@@ -4,10 +4,10 @@ from .data_model.study import Study
 import compute
 from compute.predict import PredictorConfigManager, PredictorDataSetManager
 import data_model
-from .datapackage import make_study_datapackage
+from flotilla.datapackage import make_study_datapackage
 import visualize
 
-__version__ = '0.2.2'
+__version__ = '0.2.3'
 
 _neural_diff_chr22 = 'http://sauron.ucsd.edu/flotilla_projects/' \
                      'neural_diff_chr22/datapackage.json'
