@@ -336,7 +336,7 @@ class PredictorConfigManager(object):
 
         self.predictor_config('ExtraTreesClassifier',
                               obj=ExtraTreesClassifier,
-                              n_features_dependent_parameters={
+                              n_features_dependent_kwargs={
                                   'max_features': PredictorConfigScalers.max_feature_scaler,
                                   'n_estimators': PredictorConfigScalers.n_estimators_scaler,
                                   'n_jobs': PredictorConfigScalers.n_jobs_scaler},
@@ -344,7 +344,7 @@ class PredictorConfigManager(object):
 
         self.predictor_config('ExtraTreesRegressor',
                               obj=ExtraTreesRegressor,
-                              n_features_dependent_parameters={
+                              n_features_dependent_kwargs={
                                   'max_features': PredictorConfigScalers.max_feature_scaler,
                                   'n_estimators': PredictorConfigScalers.n_estimators_scaler,
                                   'n_jobs': PredictorConfigScalers.n_jobs_scaler},
@@ -405,7 +405,7 @@ class PredictorConfigManager(object):
     def new_predictor_config(self, name, obj=None,
                              predictor_scoring_fun=None,
                              score_cutoff_fun=None,
-                             n_features_dependent_parameters=None,
+                             n_features_dependent_kwargs=None,
                              **kwargs):
         """Create a new predictor configuration
 
@@ -445,12 +445,12 @@ class PredictorConfigManager(object):
         if obj is None:
             # If obj is None, then this is probably just a "name" and you can't
             # change any of the parameters
-            n_features_dependent_parameters = None if \
-                n_features_dependent_parameters == {} else \
-                n_features_dependent_parameters
+            n_features_dependent_kwargs = None if \
+                n_features_dependent_kwargs == {} else \
+                n_features_dependent_kwargs
             kwargs = None if kwargs == {} else kwargs
             args = [predictor_scoring_fun, score_cutoff_fun,
-                    n_features_dependent_parameters, kwargs]
+                    n_features_dependent_kwargs, kwargs]
             if any([i is not None for i in args]):
                 # if obj is None, you'd better not be asking to set parameters
                 # on it.
@@ -467,16 +467,16 @@ class PredictorConfigManager(object):
         if score_cutoff_fun is None:
             score_cutoff_fun = default_score_cutoff_fun
 
-        if n_features_dependent_parameters is not None:
-            if type(n_features_dependent_parameters) is not dict:
+        if n_features_dependent_kwargs is not None:
+            if type(n_features_dependent_kwargs) is not dict:
                 raise TypeError
         else:
-            n_features_dependent_parameters = {}
+            n_features_dependent_kwargs = {}
 
         return PredictorConfig(
             name, obj, predictor_scoring_fun=predictor_scoring_fun,
             score_cutoff_fun=score_cutoff_fun,
-            n_features_dependent_kwargs=n_features_dependent_parameters,
+            n_features_dependent_kwargs=n_features_dependent_kwargs,
             **kwargs)
 
 
@@ -752,6 +752,9 @@ class PredictorDataSetManager(object):
 class PredictorBase(object):
     """A dataset-predictor pair from PredictorDatasetManager
 
+    One datset, one predictor, from dataset manager.
+
+
     Parameters
     ----------
     predictor_name : str
@@ -881,7 +884,7 @@ class PredictorBase(object):
                                       obj=self.predictor_obj,
                                       predictor_scoring_fun=self.predictor_scoring_fun,
                                       score_cutoff_fun=self.score_cutoff_fun,
-                                      n_features_dependent_parameters=self.n_features_dependent_kwargs,
+                                      n_features_dependent_kwargs=self.n_features_dependent_kwargs,
                                       **self.constant_kwargs)
 
     def fit(self):
