@@ -12,7 +12,8 @@ from sklearn.preprocessing import StandardScaler
 from ..compute.decomposition import DataFramePCA, DataFrameNMF
 # from ..compute.clustering import Cluster
 from ..compute.infotheory import binify
-from ..compute.predict import PredictorConfigManager, PredictorDataSetManager
+from ..compute.predict import PredictorConfigManager, \
+    PredictorDataSetManager, CLASSIFIER
 from ..visualize.decomposition import DecompositionViz
 from ..visualize.generic import violinplot, nmf_space_transitions, \
     simple_twoway_scatter
@@ -21,13 +22,14 @@ from ..visualize.predict import ClassifierViz
 from ..util import memoize, cached_property
 from ..compute.outlier import OutlierDetection
 
-default_predictor_name = "ExtraTreesClassifier"
 MINIMUM_FEATURE_SUBSET = 20
 
 
 class BaseData(object):
-    """Base class for biological data measurements. All data types in flotilla
-    inherit from this
+    """Base class for biological data measurements.
+
+    All data types in flotilla inherit from this, and have all functionality
+    described here
 
     Attributes
     ----------
@@ -329,30 +331,13 @@ class BaseData(object):
         from the mean variance"""
         return self.data.columns[self.data.var() > self._var_cut]
 
-    def drop_outliers(self, data, outliers):
-        """Remove outlier samples from this data"""
-        not_in_index = set(outliers).difference(data.index)
-        if len(not_in_index) >= 1:
-            sys.stderr.write("These outlier samples are not in the index, "
-                             "skipping them..."
-                             "\n\t{}\n".format("\n\t".join(not_in_index)))
-        outliers = set(outliers).intersection(data.index)
-
-        try:
-            # Remove pooled samples, if there are any
-            pooled_cells = outliers.intersection(self.pooled.index)
-            if len(pooled_cells) >= 1:
-                sys.stderr.write("These samples are pooled,"
-                                 "not outliers. Skipping..."
-                                 "\n\t{}\n".format("\n\t".join(pooled_cells)))
-            outliers = outliers.difference(self.pooled.index)
-        except AttributeError:
-            pass
-
-        sys.stdout.write("dropping {}\n".format(outliers))
-        data = data.drop(outliers)
-        outlier_data = data.ix[outliers]
-        return data, outlier_data
+    # def drop_outliers(self, data, outliers):
+    #     # assert 'outlier' din self.experiment_design_data.columns
+    #     outliers = set(outliers).intersection(data.index)
+    #     sys.stdout.write("Dropping {}\n".format(outliers))
+    #     data = data.drop(outliers)
+    #     outlier_data = data.ix[outliers]
+    #     return data, outlier_data
 
     @property
     def feature_subsets(self):
@@ -480,7 +465,7 @@ class BaseData(object):
         # local_plotting_args = self.pca_plotting_args.copy()
         # local_plotting_args.update(plotting_kwargs)
         if predictor_name is None:
-            predictor_name = default_predictor_name
+            predictor_name = CLASSIFIER
 
         classifier = self.classify(trait, sample_ids=sample_ids,
                             feature_ids=feature_ids,
@@ -565,6 +550,7 @@ class BaseData(object):
                                       label_to_color=label_to_color,
                                       label_to_marker=label_to_marker,
                                       groupby=groupby, order=order,
+                                      data_type=self.data_type,
                                       x_pc="pc_" + str(x_pc),
                                       y_pc="pc_" + str(y_pc))
         # pca(show_vectors=True,
@@ -959,8 +945,7 @@ class BaseData(object):
         return subset, row_linkage, col_linkage
 
     def binify(self, data, bins=None):
-        return binify(data, bins).dropna(how='all', axis=0).dropna(how='all',
-                                                                   axis=1)
+        return binify(data, bins).dropna(how='all', axis=1)
 
 
     def _violinplot(self, feature_id, sample_ids=None,
@@ -999,9 +984,11 @@ class BaseData(object):
         return DataFrameNMF(self.binify(data).T, n_components=2)
 
     @memoize
-    def binned_nmf_reduced(self, sample_ids=None, feature_ids=None):
-        data = self._subset(self.data, sample_ids, feature_ids,
-                            require_min_samples=False)
+    def binned_nmf_reduced(self, sample_ids=None, feature_ids=None,
+                           data=None):
+        if data is None:
+            data = self._subset(self.data, sample_ids, feature_ids,
+                                require_min_samples=False)
         binned = self.binify(data)
         reduced = self.nmf.transform(binned.T)
         return reduced
@@ -1011,19 +998,26 @@ class BaseData(object):
                      phenotype_order=None, color=None,
                      phenotype_to_color=None,
                      phenotype_to_marker=None, xlabel=None, ylabel=None,
-                     nmf_space=False):
+                     nmf_space=False, fig=None, axesgrid=None):
         """
-        Plot the violinplot of a splicing event (should also show NMF movement)
+        Plot the violinplot of a feature. Have the option to show NMF movement
         """
         feature_ids = self.maybe_renamed_to_feature_id(feature_id)
 
         if not isinstance(feature_ids, pd.Index):
             feature_ids = [feature_id]
 
-        ncols = 2 if nmf_space else 1
+        if fig is None and axesgrid is None:
+            nrows = len(feature_ids)
+            ncols = 2 if nmf_space else 1
+            figsize = 4*ncols, 4*nrows
 
-        for feature_id in feature_ids:
-            fig, axes = plt.subplots(ncols=ncols, figsize=(4 * ncols, 4))
+            fig, axesgrid = plt.subplots(nrows=nrows, ncols=ncols,
+                                         figsize=figsize)
+            if nrows == 1:
+                axesgrid = [axesgrid]
+
+        for feature_id, axes in zip(feature_ids, axesgrid):
             if not nmf_space:
                 axes = [axes]
             # if self.data_type == 'expression':
@@ -1046,11 +1040,27 @@ class BaseData(object):
                     continue
             sns.despine()
 
-    def nmf_space_positions(self, groupby, min_samples_per_group=5):
-        data = self.data.groupby(groupby).filter(
-            lambda x: len(x) >= min_samples_per_group)
-        df = data.groupby(groupby).apply(
-            lambda x: self.binned_nmf_reduced(sample_ids=x.index))
+    def nmf_space_positions(self, groupby, n=5):
+        """Calculate NMF-space position of splicing events in phenotype groups
+
+        Parameters
+        ----------
+        groupby : mappable
+            A sample id to phenotype mapping
+        n : int
+            Minimum samples required per group
+
+        Returns
+        -------
+        df : pandas.DataFrame
+            A (n_events, n_groups) dataframe of NMF positions
+        """
+        grouped = self.singles.groupby(groupby)
+        at_least_n_per_group_per_event = grouped.transform(
+            lambda x: x if x.count() >= n else pd.Series(np.nan,
+                                                         index=x.index))
+        df = at_least_n_per_group_per_event.groupby(groupby).apply(
+            lambda x: self.binned_nmf_reduced(data=x))
         df = df.swaplevel(0, 1)
         df = df.sort_index()
         return df
@@ -1067,45 +1077,143 @@ class BaseData(object):
                               ax, xlabel, ylabel)
 
     @staticmethod
-    def transition_distances(df, transitions):
-        df.index = df.index.droplevel(0)
+    def transition_distances(positions, transitions):
+        """Get NMF distance of features between phenotype transitions
+
+        Parameters
+        ----------
+        positions : pandas.DataFrame
+            A ((n_features, phenotypes), 2) MultiIndex dataframe of the NMF
+            positions of splicing events for different phenotypes
+        transitions : list of 2-string tuples
+            List of (phenotype1, phenotype2) transitions
+
+        Returns
+        -------
+        transitions : pandas.DataFrame
+            A (n_features, n_transitions) DataFrame of the NMF distances
+            of features between different phenotypes
+        """
+        positions_phenotype = positions.copy()
+        positions_phenotype.index = positions_phenotype.index.droplevel(0)
         distances = pd.Series(index=transitions)
         for transition in transitions:
             try:
                 phenotype1, phenotype2 = transition
-                norm = np.linalg.norm(df.ix[phenotype2] - df.ix[phenotype1])
+                norm = np.linalg.norm(positions_phenotype.ix[phenotype2] -
+                                      positions_phenotype.ix[phenotype1])
                 # print phenotype1, phenotype2, norm
                 distances[transition] = norm
             except KeyError:
                 pass
         return distances
 
-    def big_nmf_space_transitions(self, groupby, phenotype_transitions):
-        nmf_space_positions = self.nmf_space_positions(groupby)
+    def nmf_space_transitions(self, groupby, phenotype_transitions, n=5):
+        """Get distance in NMF space of different splicing events
+
+        Parameters
+        ----------
+        groupby : mappable
+            A sample id to phenotype mapping
+        phenotype_transitions : list of str pairs
+            Which phenotype follows from one to the next, for calculating
+            distances between
+        n : int
+            Minimum number of samples per phenotype, per event
+
+        Returns
+        -------
+        nmf_space_transitions : pandas.DataFrame
+            A (n_events, n_phenotype_transitions) sized DataFrame of the
+            distances of these events in NMF space
+        """
+        nmf_space_positions = self.nmf_space_positions(groupby, n=n)
+
+        # Take only splicing events that have at least two phenotypes
+        nmf_space_positions = nmf_space_positions.groupby(
+            level=0, axis=0).filter(lambda x: len(x) > 1)
+
         nmf_space_transitions = nmf_space_positions.groupby(
-            level=0, axis=0, as_index=False, group_keys=False).apply(
-            self.transition_distances,
-            transitions=phenotype_transitions)
+            level=0, axis=0, as_index=True, group_keys=False).apply(
+            self.transition_distances, transitions=phenotype_transitions)
+
+        # Remove any events that didn't have phenotype pairs from
+        # the transitions
+        nmf_space_transitions = nmf_space_transitions.dropna(how='all',
+                                                             axis=0)
+        return nmf_space_transitions
+
+    def big_nmf_space_transitions(self, groupby, phenotype_transitions, n=5):
+        """Get features whose change in NMF space between phenotypes is large
+
+        Parameters
+        ----------
+        groupby : mappable
+            A sample id to phenotype group mapping
+        phenotype_transitions : list of length-2 tuples of str
+            List of ('phenotype1', 'phenotype2') transitions whose change in
+            distribution you are interested in
+        n : int
+            Minimum number of samples per phenotype, per event
+
+        Returns
+        -------
+        big_transitions : pandas.DataFrame
+            A (n_events, n_transitions) dataframe of the NMF distances between
+            splicing events
+        """
+        nmf_space_transitions = self.nmf_space_transitions(
+            groupby, phenotype_transitions, n=n)
+
+        # get the mean and standard dev of the whole array
+        n = nmf_space_transitions.count().sum()
+        mean = nmf_space_transitions.sum().sum() / n
+        std = np.sqrt(np.square(nmf_space_transitions - mean).sum().sum() / n)
 
-        mean = nmf_space_transitions.mean()
-        std = nmf_space_transitions.std()
         big_transitions = nmf_space_transitions[
-            nmf_space_transitions > (mean + 2 * std)].dropna(how='all')
+            nmf_space_transitions > (mean + 2*std)].dropna(how='all')
         return big_transitions
 
     def plot_big_nmf_space_transitions(self, phenotype_groupby,
                                        phenotype_transitions,
                                        phenotype_order, color,
                                        phenotype_to_color,
-                                       phenotype_to_marker):
+                                       phenotype_to_marker, n=5):
+        """Violinplots and NMF transitions of features different in phenotypes
+
+        Plot violinplots and NMF-space transitions of features that have large
+        NMF-space transitions between different phenotypes
+
+        Parameters
+        ----------
+        n : int
+            Minimum number of samples per phenotype, per event
+
+
+        Returns
+        -------
+
+
+        Raises
+        ------
+        """
         big_transitions = self.big_nmf_space_transitions(phenotype_groupby,
-                                                         phenotype_transitions)
+                                                         phenotype_transitions,
+                                                         n=n)
+        nrows = big_transitions.shape[0]
+        ncols = 2
+        figsize = 4 * ncols, 4 * nrows
+
+        fig, axesgrid = plt.subplots(nrows=nrows, ncols=ncols,
+                                     figsize=figsize)
+        if nrows == 1:
+            axesgrid = [axesgrid]
         for feature_id in big_transitions.index:
             self.plot_feature(feature_id, phenotype_groupby=phenotype_groupby,
                               phenotype_order=phenotype_order, color=color,
                               phenotype_to_color=phenotype_to_color,
                               phenotype_to_marker=phenotype_to_marker,
-                              nmf_space=True)
+                              nmf_space=True, fig=fig, axesgrid=axesgrid)
 
 
     def plot_two_samples(self, sample1, sample2, **kwargs):
