@@ -24,6 +24,7 @@ class ExpressionData(BaseData):
 
         """
         sys.stdout.write("{}\tInitializing expression\n".format(timestamp()))
+
         super(ExpressionData, self).__init__(
             data, feature_data=feature_data,
             feature_rename_col=feature_rename_col,
@@ -31,7 +32,9 @@ class ExpressionData(BaseData):
             thresh=thresh,
             outliers=outliers, pooled=pooled, minimum_samples=minimum_samples,
             predictor_config_manager=predictor_config_manager,
-            technical_outliers=technical_outliers, data_type='expression')
+            technical_outliers=technical_outliers)
+        self.data_type = 'expression'
+        self.thresh = thresh
 
         if plus_one:
             self.data += 1
@@ -106,7 +109,6 @@ class SpikeInData(ExpressionData):
                                           technical_outliers=technical_outliers,
                                           predictor_config_manager=predictor_config_manager)
 
-
         # def spikeins_violinplot(self):
         # import matplotlib.pyplot as plt
         #     import seaborn as sns
@@ -178,4 +180,3 @@ class SpikeInData(ExpressionData):
         #             ax.set_xlim(0, tpm.shape[1])
         #             ax.set_ylabel('$\\log_2$ TPM')
         #         sns.despine()
-
