@@ -9,6 +9,7 @@ import seaborn as sns
 
 from .base import BaseData
 from ..compute.splicing import Modalities
+from ..compute.decomposition import DataFramePCA
 from ..visualize.color import purples
 from ..visualize.splicing import ModalitiesViz
 from ..util import memoize, timestamp
@@ -27,6 +28,8 @@ class SplicingData(BaseData):
     n_components = 2
     _binsize = 0.1
 
+    included_label = 'included >>'
+    excluded_label = 'excluded >>'
 
     def __init__(self, data,
                  feature_data=None, binsize=0.1, outliers=None,
@@ -64,7 +67,7 @@ class SplicingData(BaseData):
             outliers=outliers, pooled=pooled,
             technical_outliers=technical_outliers,
             predictor_config_manager=predictor_config_manager,
-            minimum_samples=minimum_samples, data_type='splicing')
+            minimum_samples=minimum_samples)
         sys.stdout.write("{}\tDone initializing splicing\n".format(timestamp()))
         self.binsize = binsize
         self.bins = np.arange(0, 1 + self.binsize, self.binsize)
@@ -282,13 +285,8 @@ class SplicingData(BaseData):
     #                       phenotype_groupby, phenotype_order,
     #                       color, phenotype_to_color, phenotype_to_marker)
 
-
-    def plot_feature(self, feature_id, sample_ids=None,
-                     phenotype_groupby=None,
-                     phenotype_order=None, color=None,
-                     phenotype_to_color=None,
-                     phenotype_to_marker=None, xlabel=None, ylabel=None,
-                     nmf_space=False):
+    @memoize
+    def _is_nmf_space_x_axis_excluded(self, phenotype_groupby):
         nmf_space_positions = self.nmf_space_positions(phenotype_groupby)
 
         # Get the correct included/excluded labeling for the x and y axes
@@ -298,21 +296,44 @@ class SplicingData(BaseData):
 
         data = self._subset(self.data, sample_ids=top_pc1_samples)
         binned = self.binify(data)
+        return bool(binned[event][0])
+    
+    def _nmf_space_xlabel(self, phenotype_groupby):
+        if self._is_nmf_space_x_axis_excluded(phenotype_groupby):
+            return self.excluded_label
+        else:
+            return self.included_label
 
-        x_axis_excluded = bool(binned[event][0])
-        included_label = 'included >>'
-        excluded_label = 'excluded >>'
-        if xlabel is None:
-            xlabel = excluded_label if x_axis_excluded else included_label
-        if ylabel is None:
-            ylabel = included_label if x_axis_excluded else excluded_label
+    def _nmf_space_ylabel(self, phenotype_groupby):
+        if self._is_nmf_space_x_axis_excluded(phenotype_groupby):
+            return self.included_label
+        else:
+            return self.excluded_label
 
+    def plot_feature(self, feature_id, sample_ids=None,
+                     phenotype_groupby=None,
+                     phenotype_order=None, color=None,
+                     phenotype_to_color=None,
+                     phenotype_to_marker=None, xlabel=None, ylabel=None,
+                     nmf_space=False, fig=None, axesgrid=None):
+        if nmf_space:
+            xlabel = self._nmf_space_xlabel(phenotype_groupby)
+            ylabel = self._nmf_space_xlabel(phenotype_groupby)
+        else:
+            ylabel = None
+            xlabel = None
+        
         super(SplicingData, self).plot_feature(feature_id, sample_ids,
                                                phenotype_groupby,
                                                phenotype_order, color,
                                                phenotype_to_color,
                                                phenotype_to_marker, xlabel,
-                                               ylabel, nmf_space=nmf_space)
+                                               ylabel, nmf_space=nmf_space,
+                                               fig=fig, axesgrid=axesgrid)
+        fig = plt.gcf()
+        for ax in fig.axes:
+            ax.set_ylim(0, 1)
+            ax.set_ylabel('$\Psi$')
 
     @memoize
     def pooled_inconsistent(self, sample_ids, feature_ids=None,
@@ -435,8 +456,8 @@ class SplicingData(BaseData):
 
     def reduce(self, sample_ids=None, feature_ids=None,
                featurewise=False,
-               reducer=None,
-               standardize=False,
+               reducer=DataFramePCA,
+               standardize=True,
                reducer_kwargs=None, bins=None):
         """
         :param sample_ids: list of sample ids
@@ -452,7 +473,7 @@ class SplicingData(BaseData):
 
         return super(SplicingData, self).reduce(sample_ids, feature_ids,
                                                 featurewise, reducer,
-                                                standardize=standardize,
+                                                standardize=False,
                                                 reducer_kwargs=reducer_kwargs,
                                                 bins=bins)
 
