@@ -247,28 +247,37 @@ class Study(object):
         else:
             self.technical_outliers = None
 
-        if self.species is not None:
-
+        if self.species is not None and (expression_feature_data is None or
+                                                 splicing_feature_data is None):
             sys.stdout.write('{}\tLoading species metadata from '
                              '~/flotilla_packages\n'.format(timestamp()))
             species_kws = self.load_species_data(self.species, self.readers)
+            expression_feature_data = species_kws.pop('expression_feature_data',
+                                                      None)
+            expression_feature_rename_col = species_kws.pop(
+                'expression_feature_rename_col', None)
+            splicing_feature_data = species_kws.pop('splicing_feature_data',
+                                                    None)
+            splicing_feature_rename_col = species_kws.pop(
+                'splicing_feature_rename_col', None)
 
             if expression_feature_data is None:
-                expression_feature_data = species_kws.pop('expression_feature_data',
+                expression_feature_data = species_kws.pop(
+                    'expression_feature_data',
                     None)
 
             if expression_feature_rename_col is None:
                 expression_feature_rename_col = species_kws.pop(
                     'expression_feature_rename_col', None)
 
-
             if splicing_feature_data is None:
-                splicing_feature_data = species_kws.pop('splicing_feature_data',
-                                                        None)
+                splicing_feature_data = species_kws.pop(
+                    'splicing_feature_data',
+                    None)
 
             if splicing_feature_rename_col is None:
                 splicing_feature_rename_col = species_kws.pop(
-                'splicing_feature_rename_col', None)
+                    'splicing_feature_rename_col', None)
 
         if expression_data is not None:
             sys.stdout.write(
@@ -316,11 +325,11 @@ class Study(object):
     @property
     def default_sample_subsets(self):
         #move default_sample_subset to the front of the list, sort the rest
-        sorted_sample_subsets = [self.default_sample_subset] + sorted(list(set(self.metadata.sample_subsets.keys(\
-            )).difference(set(self.default_sample_subset))))
-        sample_subsets_and_logcal_nots = sorted_sample_subsets + map(lambda x: "~{}".format(x),
-                                                                     sorted_sample_subsets)
-        return sample_subsets_and_logcal_nots
+        sorted_sample_subsets = list(sorted(list(set(
+            self.metadata.sample_subsets.keys()).difference(
+            set(self.default_sample_subset)))))
+        sorted_sample_subsets.insert(0, self.default_sample_subset)
+        return sorted_sample_subsets
 
     @property
     def default_feature_subsets(self):
@@ -576,20 +585,8 @@ class Study(object):
         replace the data in self.expression and self.splicing with the smaller version"""
         outliers = self.metadata.data['outlier'][
             self.metadata.data['outlier']].index
-        try:
-            sys.stdout.write("dropping expression outliers\n")
-
-            self.expression.data = \
-            self.expression.drop_outliers(self.expression.data, outliers)[0]
-        except:
-            sys.stderr.write("couldn't drop expression outliers\n")
-
-        try:
-            sys.stdout.write("dropping splicing outliers\n")
-            self.splicing.data = \
-            self.splicing.drop_outliers(self.splicing.data, outliers)[0]
-        except:
-            sys.stderr.write("couldn't drop splicing outliers")
+        self.expression.outlier_samples = outliers
+        self.splicing.outlier_samples = outliers
 
     def jsd(self):
         """Performs Jensen-Shannon Divergence on both splicing and expression
@@ -856,7 +853,8 @@ class Study(object):
         except KeyError:
             trait_ids = self.metadata.sample_subsets[trait]
             trait_data = self.metadata.data.index.isin(trait_ids)
-        if all(trait_data == True) or all(trait_data == False) or len(set(trait_data)) <= 1:
+        if all(trait_data == True) or all(trait_data == False) or len(
+                set(trait_data)) <= 1:
             raise ValueError("All samples are True (or all samples are "
                              "False) or all are the same, cannot classify"
                              "when all samples are the same")
@@ -1020,7 +1018,7 @@ class Study(object):
                     bootstrapped_kws=bootstrapped_kws)
 
     def plot_event(self, feature_id, sample_subset=None, nmf_space=False):
-        """Plot the violinplot and DataFrameNMF transitions of a splicing event
+        """Plot the violinplot and NMF transitions of a splicing event
         """
         sample_ids = self.sample_subset_to_sample_ids(sample_subset)
         self.splicing.plot_feature(feature_id, sample_ids,
@@ -1135,17 +1133,17 @@ class Study(object):
     #             metric=metric, sample_colors=sample_colors, figsize=figsize)
 
 
-    def plot_big_nmf_space_transitions(self, data_type='expression'):
+    def plot_big_nmf_space_transitions(self, data_type='expression', n=5):
         if data_type == 'expression':
             self.expression.plot_big_nmf_space_transitions(
                 self.sample_id_to_phenotype, self.phenotype_transitions,
                 self.phenotype_order, self.phenotype_color_ordered,
-                self.phenotype_to_color, self.phenotype_to_marker)
+                self.phenotype_to_color, self.phenotype_to_marker, n=n)
         if data_type == 'splicing':
             self.splicing.plot_big_nmf_space_transitions(
                 self.sample_id_to_phenotype, self.phenotype_transitions,
                 self.phenotype_order, self.phenotype_color_ordered,
-                self.phenotype_to_color, self.phenotype_to_marker)
+                self.phenotype_to_color, self.phenotype_to_marker, n=n)
 
 
     def plot_two_samples(self, sample1, sample2, data_type='expression',
@@ -1210,6 +1208,65 @@ class Study(object):
                 feature1, feature2, groupby=self.sample_id_to_phenotype,
                 label_to_color=self.phenotype_to_color, **kwargs)
 
+    def nmf_space_positions(self, data_type='splicing'):
+        if data_type == 'splicing':
+            return self.splicing.nmf_space_positions(
+                self.sample_id_to_phenotype)
+
+    def nmf_space_transitions(self, phenotype_transitions='all',
+                              data_type='splicing', n=5):
+        """The change in NMF space of splicing events across phenotypes
+
+        Parameters
+        ----------
+        phenotype_transitions : list of length-2 tuples of str
+            List of ('phenotype1', 'phenotype2') transitions whose change in
+            distribution you are interested in
+        data_type : 'splicing' | 'expression'
+            Which data type to calculate this on. (default='splicing')
+        n : int
+            Minimum number of samples per phenotype, per event
+
+        Returns
+        -------
+        big_transitions : pandas.DataFrame
+            A (n_events, n_transitions) dataframe of the NMF distances between
+            splicing events
+        """
+        if phenotype_transitions == 'all':
+            phenotype_transitions = self.phenotype_transitions
+        if data_type == 'splicing':
+            return self.splicing.nmf_space_transitions(
+                self.sample_id_to_phenotype, phenotype_transitions, n=n)
+
+    def big_nmf_space_transitions(self, phenotype_transitions='all',
+                                  data_type='splicing', n=5):
+        """Splicing events whose change in NMF space is large
+
+        By large, we mean that difference is 2 standard deviations away from
+        the mean
+
+        Parameters
+        ----------
+        phenotype_transitions : list of length-2 tuples of str
+            List of ('phenotype1', 'phenotype2') transitions whose change in
+            distribution you are interested in
+        data_type : 'splicing' | 'expression'
+            Which data type to calculate this on. (default='splicing')
+        n : int
+            Minimum number of samples per phenotype, per event
+
+        Returns
+        -------
+        big_transitions : pandas.DataFrame
+            A (n_events, n_transitions) dataframe of the NMF distances between
+            splicing events
+        """
+        if phenotype_transitions == 'all':
+            phenotype_transitions = self.phenotype_transitions
+        if data_type == 'splicing':
+            return self.splicing.big_nmf_space_transitions(
+                self.sample_id_to_phenotype, phenotype_transitions, n=n)
 
     def save(self, name, flotilla_dir=FLOTILLA_DOWNLOAD_DIR):
 
