@@ -397,13 +397,10 @@ class DecompositionViz(object):
         nrows = 1
         vector_labels = list(set(self.magnitudes[:self.n_vectors].index.union(
             pd.Index(self.top_features))))
-
-
         while ncols * nrows < len(vector_labels):
             nrows += 1
         self.violins_fig, axes = plt.subplots(nrows=nrows, ncols=ncols,
-                                              figsize=(4 * ncols, 4 * nrows),
-                                              sharey=False)
+                                              figsize=(4 * ncols, 4 * nrows))
 
         if self.feature_renamer is not None:
             renamed_vectors = map(self.feature_renamer, vector_labels)
@@ -419,16 +416,31 @@ class DecompositionViz(object):
                 None
             outliers = self.outliers[feature_id] if self.outliers is not None \
                 else None
-            if feature_id != renamed:
+
+            if isinstance(feature_id, tuple):
+                feature_id = feature_id[0][:20]
+            if renamed != feature_id:
                 title = '{}\n{}'.format(feature_id, renamed)
             else:
                 title = feature_id
+            singles.name = renamed
+            pooled.name = renamed
+            outliers.name = renamed
+            # import pdb; pdb.set_trace()
             violinplot(singles, pooled_data=pooled, outliers=outliers,
                        groupby=self.groupby, color_ordered=self.color_ordered,
                        order=self.order, title=title,
                        ax=ax, data_type=self.data_type,
                        **self.violinplot_kws)
 
+            if self.data_type == 'splicing':
+                ax.set_ylabel('$\Psi$')
+                ax.set_ylim(0, 1)
+            elif self.data_type == 'expression':
+                ax.set_ylabel('Expression')
+            else:
+                ax.set_ylabel('')
+
         # Clear any unused axes
         for ax in axes.flat:
             # Check if the plotting space is empty
