@@ -10,7 +10,8 @@ import matplotlib.pyplot as plt
 
 
 
-# from ..compute.predict import CLASSIFIER
+
+# from ..compute.predict import default_classifier
 from flotilla.util import link_to_list
 from ..visualize.color import red
 from .network import NetworkerViz
@@ -91,8 +92,8 @@ class Interactive(object):
                         featurewise=False,
                         x_pc=(1, 10), y_pc=(1, 10),
                         show_point_labels=False,
-                        list_link='', plot_violins=False,
-                        savefile=''):
+                        list_link='', plot_violins=True,
+                        savefile='data/last.pca.pdf'):
 
         def do_interact(data_type='expression',
                         sample_subset=self.default_sample_subsets,
@@ -102,7 +103,7 @@ class Interactive(object):
                         x_pc=1, y_pc=2,
                         plot_violins=True,
                         show_point_labels=False,
-                        savefile=''):
+                        savefile='data/last.pca.pdf'):
 
             for k, v in locals().iteritems():
                 if k == 'self':
@@ -146,6 +147,9 @@ class Interactive(object):
                 if plot_violins:
                     pca.violins_fig.savefig(violins_file)
 
+
+        # self.plot_study_sample_legend()
+
         if feature_subsets is None:
             feature_subsets = Interactive.get_feature_subsets(self, data_types)
 
@@ -175,7 +179,7 @@ class Interactive(object):
                           weight_fun=None,
                           use_pc_1=True, use_pc_2=True, use_pc_3=True,
                           use_pc_4=True,
-                          savefile=''):
+                          savefile='data/last.graph.pdf'):
 
         from IPython.html.widgets import interact
 
@@ -191,7 +195,7 @@ class Interactive(object):
                         cov_std_cut=1.8, n_pcs=5,
                         feature_of_interest="RBFOX2",
                         draw_labels=False,
-                        savefile=''):
+                        savefile='data/last.graph.pdf'):
 
             for k, v in locals().iteritems():
                 if k == 'self':
@@ -254,7 +258,7 @@ class Interactive(object):
                                predictor_types=None,
                                score_coefficient=(0.1, 20),
                                draw_labels=False,
-                               savefile=''):
+                               savefile='data/last.clf.pdf'):
 
         def do_interact(data_type,
                         sample_subset,
@@ -262,7 +266,7 @@ class Interactive(object):
                         predictor_type=default_classifier,
                         categorical_variable='outlier',
                         score_coefficient=2,
-                        savefile=''):
+                        savefile='data/last.clf.pdf'):
 
             for k, v in locals().iteritems():
                 if k == 'self':
@@ -416,7 +420,7 @@ class Interactive(object):
             bootstrapped_kws = {}
 
         return interact(do_interact,
-                        swample_subset=sample_subsets,
+                        sample_subset=sample_subsets,
                         feature_subset=feature_subsets,
                         color=color, x_offset=x_offset,
                         use_these_modalities=use_these_modalities,
@@ -577,8 +581,8 @@ class Interactive(object):
         # @staticmethod
         # def interactive_clusteredheatmap(self):
         # def do_interact(data_type='expression',
-        #                     sample_subset=self.default_sample_subsets,
-        #                     feature_subset=self.default_feature_subset,
+        # sample_subset=self.default_sample_subsets,
+        # feature_subset=self.default_feature_subset,
         #                     metric='euclidean',
         #                     linkage_method='median',
         #                     list_link='',
